@@ -1,5 +1,4 @@
 /*
- *  This file is part of x86info
  *  (C) 2001-2006 Dave Jones.
  *
  *  Licensed under the terms of the GNU GPL License version 2.
@@ -10,7 +9,7 @@
 #include <stdio.h>
 #include "x86info.h"
 
-void flag_decode(unsigned long reg, const char *flags[])
+static void flag_decode(unsigned long reg, const char *flags[])
 {
 	unsigned int i;
 
@@ -25,9 +24,23 @@ void flag_decode(unsigned long reg, const char *flags[])
 }
 
 
-void decode_feature_flags(struct cpudata *cpu)
+void get_feature_flags(struct cpudata *cpu)
 {
-	unsigned long eax, ebx, ecx, edx;
+	unsigned int eax, ebx, ecx, edx;
+
+	cpuid(cpu->number, 0x00000001, &eax, &ebx, &ecx, &edx);
+	cpu->flags_ecx = ecx;
+	cpu->flags_edx = edx;
+	if (cpu->maxei >= 0x80000001) {
+		cpuid(cpu->number, 0x80000001, &eax, &ebx, &ecx, &edx);
+		cpu->eflags_ecx = ecx;
+		cpu->eflags_edx = edx;
+	}
+}
+
+void show_feature_flags(struct cpudata *cpu)
+{
+	unsigned int eax, ebx, ecx, edx;
 	unsigned int i;
 
 	/* CPUID 0x00000001 EDX flags */
@@ -45,7 +58,7 @@ void decode_feature_flags(struct cpudata *cpu)
 		"Time Stamp Counter",
 		"Model-Specific Registers",
 		"Physical Address Extensions",
-		"Machine Check Architecture",
+		"Machine Check Exception",
 		"CMPXCHG8 instruction",
 		"Onboard APIC",
 		NULL,
@@ -135,27 +148,15 @@ void decode_feature_flags(struct cpudata *cpu)
 		NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL
 	};
 
-	cpuid(cpu->number, 0x00000001, &eax, &ebx, &ecx, &edx);
-	cpu->flags_ecx = ecx;
-	cpu->flags_edx = edx;
-	if (cpu->maxei >= 0x80000001) {
-		cpuid(cpu->number, 0x80000001, &eax, &ebx, &ecx, &edx);
-		cpu->eflags_ecx = ecx;
-		cpu->eflags_edx = edx;
-	}
-
-	if (silent != 0)
-		return;
-
-	printf ("Feature flags:\n");
+	printf("Feature flags:\n");
 	for (i=0; i<32; i++) {
 		if (cpu->flags_edx & (1 << i)) {
 			if (!(generic_cap_flags_desc[i]))
 				printf(" [%u]", i);
 			if (verbose)
-				printf ("\t%s\n", generic_cap_flags_desc[i]);
+				printf("\t%s\n", generic_cap_flags_desc[i]);
 			else
-				printf (" %s", generic_cap_flags[i]);
+				printf(" %s", generic_cap_flags[i]);
 		}
 	}
 
@@ -164,20 +165,20 @@ void decode_feature_flags(struct cpudata *cpu)
 		case VENDOR_AMD:
 			for (i=0; i<32; i++) {
 				if (cpu->flags_ecx & (1 << i) && amd_cap_generic_ecx_flags[i])
-					printf (" %s", amd_cap_generic_ecx_flags[i]);
+					printf(" %s", amd_cap_generic_ecx_flags[i]);
 			}
 			printf("\n");
 			if (cpu->maxei < 0x80000001)
 				break;
-			printf ("Extended feature flags:\n");
+			printf("Extended feature flags:\n");
 			flag_decode(cpu->eflags_edx, amd_cap_extended_edx_flags);
 			flag_decode(cpu->eflags_ecx, amd_cap_extended_ecx_flags);
 			printf("\n");
 			break;
 
 		case VENDOR_CENTAUR:
-			printf ("\n");
-			printf ("Extended feature flags:\n");
+			printf("\n");
+			printf("Extended feature flags:\n");
 			flag_decode(cpu->flags_ecx, centaur_cap_extended_ecx_flags);
 			cpuid(cpu->number, 0xc0000000, &eax, &ebx, &ecx, &edx);
 			if (eax >=0xc0000001) {
@@ -188,22 +189,22 @@ void decode_feature_flags(struct cpudata *cpu)
 			break;
 
 		case VENDOR_TRANSMETA:
-			printf ("\n");
-			printf ("Extended feature flags:\n");
+			printf("\n");
+			printf("Extended feature flags:\n");
 			flag_decode(cpu->flags_ecx, transmeta_cap_flags);
 			break;
 
 		case VENDOR_CYRIX:
-			printf ("\n");
+			printf("\n");
 			break;
 
 		case VENDOR_INTEL:
-			printf ("\n");
-			printf ("Extended feature flags:\n");
+			printf("\n");
+			printf("Extended feature flags:\n");
 			flag_decode(cpu->flags_ecx, intel_cap_generic_ecx_flags);
 			if (cpu->maxei < 0x80000001)
 				break;
-			printf ("\n");
+			printf("\n");
 			flag_decode(cpu->eflags_edx, intel_cap_extended_edx_flags);
 			flag_decode(cpu->eflags_ecx, intel_cap_extended_ecx_flags);
 			break;
@@ -213,5 +214,5 @@ void decode_feature_flags(struct cpudata *cpu)
 			break;
 	}
 
-	printf ("\n");
+	printf("\n");
 }
