@@ -1,12 +1,9 @@
 /*
- *  $Id: get_model_name.c,v 1.4 2003/06/13 11:36:20 davej Exp $
- *  This file is part of x86info.
  *  (C) 2001 Dave Jones.
  *
  *  Licensed under the terms of the GNU GPL License version 2.
  *
  *  Get CPU name string from cpuid.
- *
  */
 
 #include <stdio.h>
@@ -16,7 +13,7 @@
 void get_model_name(struct cpudata *cpu)
 {
 	unsigned int i, j;
-	unsigned long eax, ebx, ecx, edx;
+	unsigned int eax, ebx, ecx, edx;
 	char namestring[49], *cp;
 
 	if (cpu->maxei < 0x80000004)
@@ -43,10 +40,10 @@ void get_model_name(struct cpudata *cpu)
 
 	/* Broken BIOS? Try to determine the model name ourselves.  */
 	if (strstr(cp, "unknown") != NULL) {
-		unsigned long vendor;
+		unsigned int vendor;
 		cpuid(cpu->number, 0, NULL, &vendor, NULL, NULL);
 		if (vendor == 0x68747541 && cpu->maxi >= 1 && cpu->maxei >= 0x80000001) { /* AMD defined flags */
-			unsigned long bid, ebid;
+			unsigned int bid, ebid;
 			cpuid(cpu->number, 0x00000001, NULL, &bid, NULL, NULL);
 			bid &= 0xff;
 			cpuid(cpu->number, 0x80000001, NULL, &ebid, NULL, NULL);
@@ -128,5 +125,5 @@ void get_model_name(struct cpudata *cpu)
 		}
 	}
 
-	printf("Processor name string: %s\n\n", cp);
+	printf("Processor name string: %s\n", cp);
 }
