@@ -23,8 +23,6 @@
  * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
- *
- *	  $Id: mptable.c,v 1.8 2005/04/25 20:54:12 davej Exp $
  */
 
 
@@ -49,20 +47,20 @@ typedef unsigned long vm_offset_t;
 
 #define DEFAULT_TOPOFMEM		0xa0000
 
-#define BIOS_BASE			   0xf0000
-#define BIOS_BASE2			  0xe0000
-#define BIOS_SIZE			   0x10000
-#define ONE_KBYTE			   1024
+#define BIOS_BASE			0xf0000
+#define BIOS_BASE2			0xe0000
+#define BIOS_SIZE			0x10000
+#define ONE_KBYTE			1024
 
-#define GROPE_AREA1			 0x80000
-#define GROPE_AREA2			 0x90000
-#define GROPE_SIZE			  0x10000
+#define GROPE_AREA1			0x80000
+#define GROPE_AREA2			0x90000
+#define GROPE_SIZE			0x10000
 
-#define PROCENTRY_FLAG_EN	   0x01
-#define PROCENTRY_FLAG_BP	   0x02
-#define IOAPICENTRY_FLAG_EN	 0x01
+#define PROCENTRY_FLAG_EN	0x01
+#define PROCENTRY_FLAG_BP	0x02
+#define IOAPICENTRY_FLAG_EN	0x01
 
-#define MAXPNSTR				132
+#define MAXPNSTR		132
 
 /* global data */
 static int pfd;			/* physical /dev/mem fd */
@@ -94,7 +92,7 @@ static tableEntry basetableEntryTypes[] =
 /* MP Floating Pointer Structure */
 typedef struct MPFPS {
 	char	signature[4];
-	u32		pap;
+	u32	pap;
 	u8	length;
 	u8	spec_rev;
 	u8	checksum;
@@ -113,7 +111,7 @@ typedef struct MPCTH {
 	u8	checksum;
 	u8	oem_id[8];
 	u8	product_id[12];
-	u32 oem_table_pointer;
+	u32	oem_table_pointer;
 	u16	oem_table_size;
 	u16	entry_count;
 	u32	apic_address;
@@ -170,6 +168,7 @@ static int readType(void)
 static void processorEntry(void)
 {
 	ProcEntry entry;
+	int t, family, model;
 
 	/* read it into local memory */
 	readEntry(&entry, sizeof(entry));
@@ -185,11 +184,14 @@ static void processorEntry(void)
 				(entry.cpuFlags & PROCENTRY_FLAG_BP) ? "BSP" : "AP",
 				(entry.cpuFlags & PROCENTRY_FLAG_EN) ? "usable" : "unusable");
 
-		printf("\t %d\t %d\t %d",
-				(int) (entry.cpuSignature >> 8) & 0x0f,
-				(int) (entry.cpuSignature >> 4) & 0x0f,
-				(int)  entry.cpuSignature & 0x0f);
-
+		t = (int) entry.cpuSignature;
+		family = (t >> 8) & 0xf;
+		model = (t >> 4) & 0xf;
+		if (family == 0xf) {
+			family += (t >> 20) & 0xff;
+			model += (t >> 12) & 0xf0;
+		}
+		printf("\t %d\t %d\t %d", family, model, t & 0xf);
 		printf("\t 0x%04x\n", entry.featureFlags);
 	}
 }
@@ -198,9 +200,9 @@ static void processorEntry(void)
 static int MPConfigTableHeader(u32 pap)
 {
 	vm_offset_t paddr;
-	mpcth_t	 cth;
+	mpcth_t cth;
 	int x;
-	int totalSize, t;
+	int totalSize;
 	int count, c;
 
 	if (pap == 0) {
@@ -230,13 +232,13 @@ static int MPConfigTableHeader(u32 pap)
 	/* process all the CPUs */
 	if (verbose_mp)
 		printf("MP Table:\n#\tAPIC ID\tVersion\tState\t\tFamily\tModel\tStep\tFlags\n");
-	for (t = totalSize, c = count; c; c--) {
+	for (c = count; c; c--) {
 		if (readType() == 0)
 			processorEntry();
 		totalSize -= basetableEntryTypes[ 0 ].length;
 	}
 	if (verbose_mp)
-		printf ("\n");
+		printf("\n");
 
 	return SMP_YES;
 }
@@ -274,7 +276,7 @@ static int apic_probe(vm_offset_t* paddr)
 	/* read CMOS for real top of mem */
 	seekEntry((vm_offset_t)TOPOFMEM_POINTER);
 	readEntry(&segment, 2);
-	--segment;						  /* less ONE_KBYTE */
+	--segment;				/* less ONE_KBYTE */
 	target = segment * 1024;
 	seekEntry(target);
 	readEntry(buffer, ONE_KBYTE);
@@ -407,9 +409,9 @@ int issmp(int verb)
 #ifdef STANDALONE
 int main()
 {
-	int	numcpu, smp;
+	int numcpu, smp;
 	numcpu = enumerate_cpus();
-	smp=issmp(1);
+	smp = issmp(1);
 	printf("SMP: %d\nCPU: %d\n", smp, numcpu);
 	return 0;
 }
