@@ -8,6 +8,7 @@
  *  Routines for reading MSRs.
  */
 
+#define _LARGEFILE64_SOURCE
 #include <stdio.h>
 #include <stdlib.h>
 #include <fcntl.h>
@@ -87,7 +88,7 @@ int read_msr(int cpu, unsigned int idx, unsigned long long *val)
 		return 0;
 	}
 
-	if (lseek(fh, idx, SEEK_CUR)==-1) {
+	if (lseek64(fh, (off64_t) idx, SEEK_CUR) == -1) {
 		perror("lseek");
 		exit(EXIT_FAILURE);
 	}
