@@ -1,6 +1,5 @@
 /*
- *  This file is part of x86info.
- *  (C) 2001-2007 Dave Jones.
+ *  (C) 2001-2009 Dave Jones.
  *
  *  Licensed under the terms of the GNU GPL License version 2.
  */
@@ -11,6 +10,9 @@
 #include <unistd.h>
 
 #include "x86info.h"
+#include "mptable.h"
+
+#include "Intel/Intel.h"
 
 int show_bench=0;
 int show_bios=0;
@@ -41,10 +43,10 @@ static unsigned int nrSMPCPUs;
 
 static void usage (char *programname)
 {
-	printf ("Usage: %s [<switches>]\n\
+	printf("Usage: %s [<switches>]\n\
 -a,   --all\n\
       --bench\n\
-	  --bios\n\
+      --bios\n\
       --bugs\n\
 -c,   --cache\n\
       --connector\n\
@@ -89,8 +91,8 @@ static void parse_command_line (int argc, char **argv)
 			need_root = 1;
 		}
 
-//		if (!strcmp(arg, "--bench"))
-//			show_bench = 1;
+		if (!strcmp(arg, "--bench"))
+			show_bench = 1;
 
 		if (!strcmp(arg, "--bios")) {
 			need_root = 1;
@@ -165,8 +167,8 @@ static void separator(void)
 	int j;
 
 	for (j=0; j<74; j++)
-		printf ("-");
-	printf ("\n");
+		printf("-");
+	printf("\n");
 }
 
 
@@ -177,37 +179,37 @@ int main (int argc, char **argv)
 
 	parse_command_line(argc, argv);
 	if (!silent) {
-		printf ("x86info v1.21.  Dave Jones 2001-2007\n");
-		printf ("Feedback to <davej@redhat.com>.\n\n");
+		printf("x86info v1.25.  Dave Jones 2001-2009\n");
+		printf("Feedback to <davej@redhat.com>.\n\n");
 	}
 
-	if ((HaveCPUID())==0) {
-		printf ("No CPUID instruction available.\n");
-		printf ("No further information available for this CPU.\n");
+	if ((HaveCPUID()) == 0) {
+		printf("No CPUID instruction available.\n");
+		printf("No further information available for this CPU.\n");
 		return 0;
 	}
 
-	if (getuid()!=0)
+	if (getuid() != 0)
 		user_is_root=0;
 
 	if (need_root && !user_is_root)
-		printf ("Need to be root to use specified options.\n");
+		printf("Need to be root to use specified options.\n");
 
-	nrCPUs = sysconf (_SC_NPROCESSORS_ONLN);
+	nrCPUs = sysconf(_SC_NPROCESSORS_ONLN);
 
 	if (!silent) {
-		printf ("Found %u CPU", nrCPUs);
+		printf("Found %u CPU", nrCPUs);
 		if (nrCPUs > 1)
-			printf ("s");
+			printf("s");
 
 		/* Check mptable if present. This way we get number of CPUs
 		   on SMP systems that have booted UP kernels. */
 		if (user_is_root) {
 			nrSMPCPUs = enumerate_cpus();
 			if (nrSMPCPUs > nrCPUs)
-				printf (", but found %ud CPUs in MPTable.", nrSMPCPUs);
+				printf(", but found %ud CPUs in MPTable.", nrSMPCPUs);
 		}
-		printf ("\n");
+		printf("\n");
 	}
 
 	/*
@@ -229,11 +231,11 @@ int main (int argc, char **argv)
 	for (i=0; i<nrCPUs; i++) {
 		cpu = malloc (sizeof (struct cpudata));
 		if (!cpu) {
-			printf ("Out of memory\n");
+			printf("Out of memory\n");
 			return -1;
 		}
 
-		memset (cpu, 0, sizeof(struct cpudata));
+		memset(cpu, 0, sizeof(struct cpudata));
 
 		if (!head) {
 			head = cpu;
@@ -244,20 +246,59 @@ int main (int argc, char **argv)
 
 		cpu->number = i;
 
-		if (!silent && nrCPUs!=1)
-			printf ("CPU #%u\n", i+1);
+		if (!silent && nrCPUs != 1)
+			printf("CPU #%u\n", i+1);
+
+		bind_cpu(cpu);
 
 		estimate_MHz(cpu);
-		identify (cpu);
-		show_info (cpu);
+		get_feature_flags(cpu);
+		get_cpu_info_basics(cpu);	/* get vendor,family,model,stepping */
+		identify(cpu);
+		show_info(cpu);
 
-		/*
-		 * Doing this per-cpu is a problem, as we can't
-		 * schedule userspace code per-cpu.
-		 * Although running nrCPUs * threads would probably work.
-		 *
-		 * Could also experiment with the new scheduler binding syscalls.
-		 */
+		if (show_registers) {
+			dumpregs(cpu->number, 0, cpu->maxi);
+			if (cpu->maxei >=0x80000000)
+				dumpregs (cpu->number, 0x80000000, cpu->maxei);
+
+			if (cpu->maxei2 >=0xC0000000)
+				dumpregs (cpu->number, 0xC0000000, cpu->maxei2);
+		}
+
+		if (show_cacheinfo == 1) {
+			switch (cpu->vendor) {
+			case VENDOR_INTEL:
+				decode_Intel_caches(cpu, 1);
+				break;
+			case VENDOR_AMD:
+				decode_AMD_cacheinfo(cpu);
+				break;
+			default:
+				break;
+			}
+		}
+
+		if (show_flags == 1)
+			show_feature_flags(cpu);
+
+		if (show_connector)
+			decode_connector(cpu->connector);
+
+		if (show_urls) {
+			if (cpu->datasheet_url != NULL)
+				printf("Datasheet: %s\n", cpu->datasheet_url);
+			if (cpu->errata_url != NULL)
+				printf("Errata: %s\n", cpu->errata_url);
+		}
+
+		/* Info that requires root access (eg, reading MSRs etc) */
+		if (user_is_root) {
+			if (show_mtrr)
+				dump_mtrrs(cpu);
+		}
+
+		/* Show MHz last. */
 		if (show_MHz) {
 			if (cpu->MHz < 1000)
 				printf("%uMHz", cpu->MHz);
@@ -268,16 +309,13 @@ int main (int argc, char **argv)
 
 				printf("%u.%u%uGHz", a, b, (cpu->MHz - c)/10);
 			}
-			printf (" processor (estimate).\n\n");
+			printf(" processor (estimate).\n\n");
 		}
 		if (show_bench)
-			show_benchmarks();
+			show_benchmarks(cpu);
 
-		if (nrCPUs>1)
+		if (nrCPUs > 1)
 			separator();
-
-		if (cpu->next)
-			cpu = cpu->next;
 	}
 
 	/* Tear down the linked list. */
@@ -292,10 +330,10 @@ int main (int argc, char **argv)
 		cpu = tmp;
 	}
 
-	if (nrCPUs > 1 && used_UP==1 && (!silent)) {
-		printf ("WARNING: Detected SMP, but unable to access cpuid driver.\n");
-		printf ("Used Uniprocessor CPU routines. Results inaccurate.\n");
+	if (nrCPUs > 1 && (used_UP == 1) && (!silent)) {
+		printf("WARNING: Detected SMP, but unable to access cpuid driver.\n");
+		printf("Used Uniprocessor CPU routines. Results inaccurate.\n");
 	}
 
-	return (0);
+	return 0;
 }
